@@ -37,7 +37,7 @@ def main_public_from_parser(method: Annotated[Literal["symlink", "s", "copy", "c
     if which is None:
         assert interactive is True
         from machineconfig.utils.options import choose_from_options
-        items_chosen = choose_from_options(msg="Which symlink to create?", options=list(mapper_full.keys()), fzf=True, multi=True)
+        items_chosen = choose_from_options(msg="Which symlink to create?", options=list(mapper_full.keys()), tv=True, multi=True)
     else:
         assert interactive is False
         if which == "all":
@@ -74,7 +74,7 @@ def main_private_from_parser(method: Annotated[Literal["symlink", "s", "copy", "
             typer.Exit(code=1)
             return
         from machineconfig.utils.options import choose_from_options
-        items_chosen = choose_from_options(msg="Which symlink to create?", options=list(mapper_full.keys()), fzf=True, multi=True)
+        items_chosen = choose_from_options(msg="Which symlink to create?", options=list(mapper_full.keys()), tv=True, multi=True)
     else:
         if interactive is True:
             typer.echo("[yellow]Warning:[/] --which is provided, but its not allowed to be used together with --interactive. Ignoring --interactive flag.")
