@@ -7,7 +7,7 @@ import typer
 from machineconfig.scripts.python.helpers_agents.fire_agents_helper_types import AGENTS, HOST, PROVIDER
 
 
-def create(
+def agents_create(
     agent: Annotated[AGENTS, typer.Option(..., "--agents", "-a", help=f"Agent type. One of {', '.join(get_args(AGENTS)[:3])}")],
     host: Annotated[HOST, typer.Option(..., "--host", "-h", help=f"Machine to run agents on. One of {', '.join(get_args(HOST))}")],
     model: Annotated[str, typer.Option(..., "--model", "-m", help="Model to use (for crush agent).")],
@@ -75,18 +75,18 @@ def create(
                       prompt_prefix=prompt_prefix, machine=host, agent=agent_selected, model=model, provider=provider,
                       job_name=job_name)
     layoutfile = get_agents_launch_layout(session_root=agents_dir_obj)
-    regenerate_py_code = f"""
-#!/usr/bin/env uv run --python 3.14 --with machineconfig
-agents create "{context_path_resolved}" \\
-    --prompt-path "{prompt_path or ''}" \\
-    --agent "{agent_selected}" \\
-    --host "{host}" \\
-    --job-name "{job_name}" \\
-    --agent_load {agent_load} \\
-    --separator "{separator}" \\
-    {"--separate" if separate else ""}
-"""
-    (agents_dir_obj / "aa_agents_relaunch.sh").write_text(data=regenerate_py_code, encoding="utf-8")
+#     regenerate_py_code = f"""
+# #!/usr/bin/env uv run --python 3.14 --with machineconfig
+# agents create "{context_path_resolved}" \\
+#     --prompt-path "{prompt_path or ''}" \\
+#     --agent "{agent_selected}" \\
+#     --host "{host}" \\
+#     --job-name "{job_name}" \\
+#     --agent_load {agent_load} \\
+#     --separator "{separator}" \\
+#     {"--separate" if separate else ""}
+# """
+#     (agents_dir_obj / "aa_agents_relaunch.sh").write_text(data=regenerate_py_code, encoding="utf-8")
     layout_output_path = Path(output_path) if output_path is not None else agents_dir_obj / "layout.json"
     layout_output_path.parent.mkdir(parents=True, exist_ok=True)
     layout_output_path.write_text(data=json.dumps(layoutfile, indent=4), encoding="utf-8")
@@ -137,6 +137,7 @@ def collect(
 
 
 def make_agents_command_template():
+    """Create a template for fire agents"""
     from platform import system
     import machineconfig.scripts.python.helpers_agents as module
     from pathlib import Path
@@ -170,10 +171,15 @@ def make_agents_command_template():
     typer.echo(f"Prompt template written to {save_path_root}")
 
 
-def init_config():
+def init_config(root: Annotated[Optional[str], typer.Option(..., "--root", "-r", help="Root directory of the repository to initialize AI configs in. Defaults to current directory.")] = None):
+    """Initialize AI configurations in the current repository"""
     from machineconfig.scripts.python.ai.initai import add_ai_configs
     from pathlib import Path
-    add_ai_configs(repo_root=Path.cwd())
+    if root is None:
+        repo_root = Path.cwd()
+    else:
+        repo_root = Path(root).expanduser().resolve()
+    add_ai_configs(repo_root=repo_root)
 
 
 def get_app():
@@ -186,20 +192,21 @@ PROVIDER options: {', '.join(get_args(PROVIDER))}
 {sep}
 AGENT options: {', '.join(get_args(AGENTS))}
 """
-    agents_app.command("create", no_args_is_help=True, help=agents_full_help)(create)
-    agents_app.command("c", no_args_is_help=True, help="Create agents layout file, ready to run.", hidden=True)(create)
-    agents_app.command("collect", no_args_is_help=True, help="[T] Collect all agent materials into a single file.")(collect)
-    agents_app.command("T", no_args_is_help=True, help="Collect all agent materials into a single file.", hidden=True)(collect)
-    agents_app.command("make-template", no_args_is_help=False, help="[t] Create a template for fire agents")(make_agents_command_template)
-    agents_app.command("t", no_args_is_help=False, help="Create a template for fire agents", hidden=True)(make_agents_command_template)
-    agents_app.command("make-config", no_args_is_help=False, help="[g] Initialize AI configurations in the current repository")(init_config)
-    agents_app.command("g", no_args_is_help=False, help="Initialize AI configurations in the current repository", hidden=True)(init_config)
+    agents_create.__doc__ = agents_full_help
+    agents_app.command("create", no_args_is_help=True, help=agents_create.__doc__, short_help="[c] Create agents layout file, ready to run.")(agents_create)
+    agents_app.command("c", no_args_is_help=True, help=agents_create.__doc__, hidden=True)(agents_create)
+    agents_app.command("collect", no_args_is_help=True, help=collect.__doc__, short_help="[T] Collect all agent materials into a single file.")(collect)
+    agents_app.command("T", no_args_is_help=True, help=collect.__doc__, hidden=True)(collect)
+    agents_app.command("make-template", no_args_is_help=False, help=make_agents_command_template.__doc__, short_help="[t] Create a template for fire agents")(make_agents_command_template)
+    agents_app.command("t", no_args_is_help=False, help=make_agents_command_template.__doc__, hidden=True)(make_agents_command_template)
+    agents_app.command("make-config", no_args_is_help=False, help=init_config.__doc__, short_help="[g] Initialize AI configurations in the current repository")(init_config)
+    agents_app.command("g", no_args_is_help=False, help=init_config.__doc__, hidden=True)(init_config)
     from machineconfig.scripts.python.ai.utils.generate_files import make_todo_files
-    agents_app.command("make-todo", no_args_is_help=True, help="[d] Generate a markdown file listing all Python files in the repo")(make_todo_files)
-    agents_app.command("d", no_args_is_help=True, help="Generate a markdown file listing all Python files in the repo", hidden=True)(make_todo_files)
+    agents_app.command("make-todo", no_args_is_help=True, help=make_todo_files.__doc__, short_help="[d] Generate a markdown file listing all Python files in the repo")(make_todo_files)
+    agents_app.command("d", no_args_is_help=True, help=make_todo_files.__doc__, hidden=True)(make_todo_files)
     from machineconfig.scripts.python.ai.utils.generate_files import create_symlink_command
-    agents_app.command(name="make-symlinks", no_args_is_help=True, help="[s] Create symlinks to the current repo in ~/code_copies/")(create_symlink_command)
-    agents_app.command(name="s", no_args_is_help=True, help="Create symlinks to the current repo in ~/code_copies/", hidden=True)(create_symlink_command)
+    agents_app.command(name="make-symlinks", no_args_is_help=True, help=create_symlink_command.__doc__, short_help="[s] Create symlinks to the current repo in ~/code_copies/")(create_symlink_command)
+    agents_app.command(name="s", no_args_is_help=True, help=create_symlink_command.__doc__, hidden=True)(create_symlink_command)
     return agents_app
 
 
