@@ -23,7 +23,7 @@ def choose_function_or_lines(choice_file: Path, kwargs_dict: dict[str, object])
     if choice_file.suffix == ".py":
         from machineconfig.scripts.python.helpers_fire_command.file_wrangler import parse_pyfile
         options, func_args = parse_pyfile(file_path=str(choice_file))
-        choice_function_tmp = choose_from_options(msg="Choose a function to run", options=options, fzf=True, multi=False)
+        choice_function_tmp = choose_from_options(msg="Choose a function to run", options=options, tv=True, multi=False)
         assert isinstance(choice_function_tmp, str), f"choice_function must be a string. Got {type(choice_function_tmp)}"
         choice_index = options.index(choice_function_tmp)
         choice_function = choice_function_tmp.split(" -- ")[0]
@@ -44,7 +44,7 @@ def choose_function_or_lines(choice_file: Path, kwargs_dict: dict[str, object])
             if line.startswith("echo"):
                 continue
             options.append(line)
-        chosen_lines = choose_from_options(msg="Choose a line to run", options=options, fzf=True, multi=True)
+        chosen_lines = choose_from_options(msg="Choose a line to run", options=options, tv=True, multi=True)
         choice_file = Path.home().joinpath(f"tmp_results/tmp_scripts/shell/{randstr(10)}.sh")
         choice_file.parent.mkdir(parents=True, exist_ok=True)
         choice_file.write_text("\n".join(chosen_lines), encoding="utf-8")
@@ -55,7 +55,7 @@ def choose_function_or_lines(choice_file: Path, kwargs_dict: dict[str, object])
 
 def get_command_streamlit(choice_file: Path, environment: str, repo_root: Optional[Path]) -> str:
     # from machineconfig.scripts.python.helpers_utils.path import get_machine_specs
-    from machineconfig.scripts.python.nw.address import select_lan_ipv4
+    from machineconfig.scripts.python.helpers_network.address import select_lan_ipv4
     res = select_lan_ipv4(prefer_vpn=False)
     if res is None:
         raise RuntimeError("Could not determine local LAN IPv4 address for streamlit app.")
