@@ -9,13 +9,12 @@ def create_from_function(
         path: Annotated[str, typer.Option(..., "--path", "-p", help="Path to a Python or Shell script file or a directory containing such files")] = ".",
         function: Annotated[Optional[str], typer.Option(..., "--function", "-f", help="Function to run from the Python file. If not provided, you will be prompted to choose.")] = None,
 ):
-    from machineconfig.utils.ve import get_ve_activate_line, get_ve_path_and_ipython_profile
+    from machineconfig.utils.ve import get_ve_path_and_ipython_profile
     from machineconfig.utils.options import choose_from_options
     from machineconfig.utils.path_helper import match_file_name, sanitize_path
     from machineconfig.utils.accessories import get_repo_root
     from pathlib import Path
 
-
     path_obj = sanitize_path(path)
     if not path_obj.exists():
         suffixes = {".py"}
@@ -36,10 +35,13 @@ def create_from_function(
     ve_root_from_file, ipy_profile = get_ve_path_and_ipython_profile(choice_file)
     if ipy_profile is None:
         ipy_profile = "default"
-    if ve_root_from_file is None:
-        raise ValueError(f"Could not determine virtual environment for file {choice_file}. Please ensure it is within a recognized project structure.")
-
-    _activate_ve_line = get_ve_activate_line(ve_root=ve_root_from_file)
+    # if ve_root_from_file is None:
+    #     raise ValueError(f"Could not determine virtual environment for file {choice_file}. Please ensure it is within a recognized project structure.")
+    # _activate_ve_line = get_ve_activate_line(ve_root=ve_root_from_file)
+    if ve_root_from_file is not None:
+        start_dir = Path(ve_root_from_file).parent
+    else:
+        start_dir = Path.cwd()
 
     # =========================  choosing function to run
     if function is None or function.strip() == "":
@@ -52,7 +54,11 @@ def create_from_function(
     from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig
     layout: LayoutConfig = {"layoutName": "fireNprocess", "layoutTabs": []}
     for an_arg in range(num_process):
-        layout["layoutTabs"].append({"tabName": f"tab{an_arg}", "startDir": str(Path.cwd()), "command": f"uv run -m fire {choice_file} {choice_function} --idx={an_arg} --idx_max={num_process}"})
+        layout["layoutTabs"].append({
+            "tabName": f"tab{an_arg}",
+            "startDir": str(start_dir),
+            "command": f"uv run python -m fire {choice_file} {choice_function} --idx={an_arg} --idx_max={num_process}"
+            })
     print(layout)
     run_zellij_layout(layout_config=layout)
 
