@@ -7,11 +7,10 @@ pointing at common scripts (so other code can import these paths).
 
 from pathlib import Path
 
-# Path to main installer script for macOS
-APPS = Path(__file__).parent.joinpath("apps.sh")
+
 # Optional helper scripts (may or may not exist)
 UV = Path(__file__).parent.joinpath("uv.sh")
 # Path to macOS SSH helper
 SSH_SETUP = Path(__file__).parent.joinpath("ssh/openssh_setup.sh")
 
-__all__ = ["APPS", "UV", "SSH_SETUP"]
+__all__ = ["UV", "SSH_SETUP"]
