@@ -4,15 +4,15 @@ from machineconfig.utils.accessories import randstr
 from pathlib import Path
 
 
-def get_uv_run_command(platform: str) -> str:
+def get_uv_command(platform: str) -> str:
     res = cast(Literal["Windows", "windows", "nt", "Linux", "linux", "Darwin", "darwin", "macos"], platform)
     match res:
         case "Windows" | "windows" | "nt":
-            return """& "$env:USERPROFILE/.local/bin/uv" run"""
+            return """& "$env:USERPROFILE/.local/bin/uv" """
         case "Linux" | "linux" | "Darwin" | "darwin" | "macos":
-            return """$HOME/.local/bin/uv run"""
+            return """$HOME/.local/bin/uv """
         case _:
-            return """$HOME/.local/bin/uv run"""
+            return """$HOME/.local/bin/uv """
 
 def print_code(code: str, lexer: str, desc: str, subtitle: str = ""):
     import platform
@@ -35,10 +35,9 @@ def print_code(code: str, lexer: str, desc: str, subtitle: str = ""):
         print(f"--- End of {desc} ---")
 
 
-def get_uv_command_executing_python_script(python_script: str, uv_with: Optional[list[str]], uv_project_dir: Optional[str],
-                                           prepend_print: bool = True) -> tuple[str, Path]:
-    python_file = Path.home().joinpath("tmp_results", "tmp_scripts", "python", randstr() + ".py")
-    python_file.parent.mkdir(parents=True, exist_ok=True)
+def get_uv_command_executing_python_file(python_file: str, uv_with: Optional[list[str]], uv_project_dir: Optional[str], 
+                                        prepend_print: bool = True, ) -> str:
+    # shell script
     if uv_with is not None and len(uv_with) > 0:
         if prepend_print: uv_with.append("rich")
         uv_with_arg = "--with " + '"' + ",".join(uv_with) + '"'
@@ -51,7 +50,17 @@ def get_uv_command_executing_python_script(python_script: str, uv_with: Optional
         uv_project_dir_arg = "--project" + f' "{uv_project_dir}"'
     else:
         uv_project_dir_arg = ""
-    
+    import platform
+
+    uv_command = get_uv_command(platform=platform.system())
+    shell_script = f"""{uv_command} run {uv_with_arg} {uv_project_dir_arg}  {str(python_file)} """
+    return shell_script
+
+
+def get_uv_command_executing_python_script(python_script: str, uv_with: Optional[list[str]], uv_project_dir: Optional[str],
+                                           prepend_print: bool = True, ) -> tuple[str, Path]:
+    python_file = Path.home().joinpath("tmp_results", "tmp_scripts", "python", randstr() + ".py")
+    python_file.parent.mkdir(parents=True, exist_ok=True)
     if prepend_print:
         from machineconfig.utils.meta import lambda_to_python_script
         print_code_string = lambda_to_python_script(lambda: print_code(code=python_script, lexer="python", desc="Temporary Python Script", subtitle="Executing via shell script"),
@@ -59,9 +68,7 @@ def get_uv_command_executing_python_script(python_script: str, uv_with: Optional
         python_file.write_text(print_code_string + "\n" + python_script, encoding="utf-8")
     else:
         python_file.write_text(python_script, encoding="utf-8")
-    import platform
-    uv_run = get_uv_run_command(platform=platform.system())
-    shell_script = f"""{uv_run} {uv_with_arg} {uv_project_dir_arg}  {str(python_file)} """
+    shell_script = get_uv_command_executing_python_file(python_file=str(python_file), uv_with=uv_with, uv_project_dir=uv_project_dir, prepend_print=prepend_print)
     return shell_script, python_file
 
 
@@ -71,6 +78,8 @@ def run_lambda_function(lmb: Callable[[], Any], uv_with: Optional[list[str]], uv
                                             in_global=True, import_module=False)
     uv_command, _py_file = get_uv_command_executing_python_script(python_script=code, uv_with=uv_with, uv_project_dir=uv_project_dir)
     run_shell_script(uv_command)
+
+
 def run_python_script_in_marimo(py_script: str, uv_project_with: Optional[str]):
     tmp_dir = Path.home().joinpath("tmp_results", "tmp_scripts", "marimo", randstr())
     tmp_dir.mkdir(parents=True, exist_ok=True)
@@ -90,35 +99,44 @@ uv run  {requirements} marimo edit --host 0.0.0.0 marimo_nb.py
     exit_then_run_shell_script(fire_line)
 
 
-def run_shell_script(script: str, display_script: bool = True, clean_env: bool = False):
-    import tempfile
+def run_shell_file(script_path: str, clean_env: bool):
     import platform
-    from rich.console import Console
-    from rich.panel import Panel
-    from rich.syntax import Syntax
+    env = {} if clean_env else None
+    if platform.system() == "Windows":
+        import subprocess
+        proc = subprocess.run(f'powershell -ExecutionPolicy Bypass -File "{script_path}"', check=True, shell=True, env=env)
+    elif platform.system() == "Linux" or platform.system() == "Darwin":
+        import subprocess
+        proc = subprocess.run(f"bash {str(script_path)}", check=True, shell=True, env=env)
+    else:
+        raise NotImplementedError(f"Platform {platform.system()} not supported.")
+    return proc
 
+
+def run_shell_script(script: str, display_script: bool = True, clean_env: bool = False) -> Any:
+
+    import platform
     if platform.system() == "Windows":
         suffix = ".ps1"
         lexer = "powershell"
     else:
         suffix = ".sh"
         lexer = "bash"
+
+    import tempfile
     with tempfile.NamedTemporaryFile(mode='w', suffix=suffix, delete=False, encoding='utf-8') as temp_file:
         temp_file.write(script)
         temp_shell_script_path = Path(temp_file.name)
+
+    from rich.panel import Panel
+    from rich.syntax import Syntax
+    from rich.console import Console
     console = Console()
     if display_script:
         from rich.syntax import Syntax
         console.print(Panel(Syntax(code=script, lexer=lexer), title=f"📄 shell script @ {temp_shell_script_path}", subtitle="shell script being executed"), style="bold red")
-    env = {} if clean_env else None
-    if platform.system() == "Windows":
-        import subprocess
-        proc = subprocess.run(f'powershell -ExecutionPolicy Bypass -File "{temp_shell_script_path}"', check=True, shell=True, env=env)
-    elif platform.system() == "Linux" or platform.system() == "Darwin":
-        import subprocess
-        proc = subprocess.run(f"bash {str(temp_shell_script_path)}", check=True, shell=True, env=env)
-    else:
-        raise NotImplementedError(f"Platform {platform.system()} not supported.")
+
+    proc = run_shell_file(script_path=str(temp_shell_script_path), clean_env=clean_env)
     # console.print(f"✅  [green]Script executed successfully:[/green] [blue]{temp_script_path}[/blue]")
     if proc.returncode != 0:
         console.print(f"❌  [red]Script execution failed with return code {proc.returncode}:[/red] [blue]{temp_shell_script_path}[/blue]")
@@ -126,6 +144,7 @@ def run_shell_script(script: str, display_script: bool = True, clean_env: bool =
         console.print(f"✅  [green]Script executed successfully:[/green] [blue]{temp_shell_script_path}[/blue]")
     else:
         console.print(f"⚠️  [yellow]Script executed with warnings (return code {proc.returncode}):[/yellow] [blue]{temp_shell_script_path}[/blue]")
+
     temp_shell_script_path.unlink(missing_ok=True)
     console.print(f"🗑️  [blue]Temporary script deleted:[/blue] [green]{temp_shell_script_path}[/green]")
     return proc
@@ -177,5 +196,3 @@ def exit_then_run_shell_script(script: str, strict: bool = False):
         run_shell_script(script)
     import sys
     sys.exit(0)
-
-
