@@ -35,7 +35,12 @@ def choose_from_options[T](options: Iterable[T], msg: str, multi: bool, custom_i
         # the interactive session completes. Do not capture_output or redirect
         # stdin/stderr here so `tv` stays attached to the terminal.
         tv_out_path = options_txt_path.with_name(options_txt_path.stem + "_out.txt")
-        tv_cmd = f"""cat {options_txt_path} | tv  --ansi true --source-output "{{strip_ansi}}" > {tv_out_path}"""
+        import platform
+        if platform.system() == "Windows":
+            cat_command = "Get-Content"
+        else:
+            cat_command = "cat"
+        tv_cmd = f"""{cat_command} {options_txt_path} | tv  --preview-command "bat -n --color=always '{{}}'" --preview-size 30 --ansi true --source-output "{{strip_ansi}}" > {tv_out_path} """
         res = subprocess.run(tv_cmd, shell=True)
     
         # If tv returned a non-zero code and there is no output file, treat it as an error.
