@@ -2,8 +2,8 @@ from typing import Callable, Optional, Any, cast, Union, Literal
 import os
 from pathlib import Path
 import platform
-from machineconfig.scripts.python.helpers_utils.path import MachineSpecs
-from machineconfig.utils.code import get_uv_run_command
+from machineconfig.scripts.python.helpers_utils.python import MachineSpecs
+from machineconfig.utils.code import get_uv_command
 import rich.console
 from machineconfig.utils.terminal import Response
 from machineconfig.utils.accessories import pprint, randstr
@@ -149,7 +149,7 @@ class SSH:
                 if self.progress and self.task is not None:
                     self.progress.update(self.task, completed=transferred, total=total)
         self.tqdm_wrap = RichProgressWrapper
-        from machineconfig.scripts.python.helpers_utils.path import get_machine_specs
+        from machineconfig.scripts.python.helpers_utils.python import get_machine_specs
         self.local_specs: MachineSpecs = get_machine_specs()
         resp = self.run_shell_cmd_on_remote(
             command="""~/.local/bin/utils get-machine-specs """,
@@ -215,9 +215,8 @@ class SSH:
         self.copy_from_here(source_path="~/.ssh/id_rsa.pub", target_rel2home=None, compress_with_zip=False, recursive=False, overwrite_existing=False)
         if self.remote_specs["system"] != "Windows":
             raise RuntimeError("send_ssh_key is only supported for Windows remote machines")
-        code_url = "https://raw.githubusercontent.com/thisismygitrepo/machineconfig/refs/heads/main/src/machineconfig/setup_windows/openssh-server_add-sshkey.ps1"
+        code_url = "https://raw.githubusercontent.com/thisismygitrepo/machineconfig/refs/heads/main/src/machineconfig/setup_windows/ssh/openssh-server_add-sshkey.ps1"
         import urllib.request
-
         with urllib.request.urlopen(code_url) as response:
             code = response.read().decode("utf-8")
         return self.run_shell_cmd_on_remote(command=code, verbose_output=True, description="", strict_stderr=False, strict_return_code=False)
@@ -274,12 +273,12 @@ class SSH:
             with_clause += ""
         match on:
             case "local":
-                uv_run_cmd = get_uv_run_command(platform=self.local_specs["system"])
+                uv_cmd = get_uv_command(platform=self.local_specs["system"])
             case "remote":
-                uv_run_cmd = get_uv_run_command(platform=self.remote_specs["system"])
+                uv_cmd = get_uv_command(platform=self.remote_specs["system"])
             case _:
                 raise ValueError(f"Invalid value for 'on': {on}. Must be 'local' or 'remote'")
-        uv_cmd = f"""{uv_run_cmd} {with_clause} python {py_path.relative_to(Path.home())}"""
+        uv_cmd = f"""{uv_cmd} run {with_clause} python {py_path.relative_to(Path.home())}"""
         return uv_cmd
 
     def run_py_remotely(
